@@ -1,10 +1,10 @@
 import pyglet
 
-from collision.collision_controller import CollisionController
-from interaction_controller import InteractionController
-from input_controller import InputController
-from inventory_controller import InventoryController, MenuController
-from sound_controller import SoundController
+from amonite.collision.collision_controller import CollisionController
+from amonite.interaction_controller import InteractionController
+from amonite.input_controller import InputController
+from amonite.inventory_controller import InventoryController, MenuController
+from amonite.sound_controller import SoundController
 
 COLLISION_CONTROLLER: CollisionController
 INPUT_CONTROLLER: InputController
