@@ -1,10 +1,10 @@
 from typing import Callable
 import pyglet
 
-from engine import controllers
-from collision.collision_node import CollisionNode
-from collision.collision_shape import CollisionRect
-from node import PositionNode
+from amonite import controllers
+from amonite.collision.collision_node import CollisionNode
+from amonite.collision.collision_shape import CollisionRect
+from amonite.node import PositionNode
 
 DOOR_COLOR: tuple[int, int, int, int] = (0xFF, 0xFF, 0x7F, 0x7F)
 
