@@ -1,9 +1,9 @@
 import pyglet
 
-from engine import controllers
-from collision.collision_node import CollisionNode, CollisionType
-from collision.collision_shape import CollisionCircle, CollisionRect
-from node import PositionNode
+from amonite import controllers
+from amonite.collision.collision_node import CollisionNode, CollisionType
+from amonite.collision.collision_shape import CollisionCircle, CollisionRect
+from amonite.node import PositionNode
 
 FALL_COLOR: tuple[int, int, int, int] = (0xFF, 0x44, 0x00, 0x7F)
 
