@@ -1,4 +1,4 @@
-from interaction_node import InteractionNode
+from amonite.interaction_node import InteractionNode
 
 
 class InteractionController:
