@@ -1,6 +1,6 @@
 from typing import Callable, Optional
 
-from node import Node
+from amonite.node import Node
 
 class InteractionNode(Node):
     """
