@@ -1,6 +1,4 @@
-from typing import Tuple
-
-from node import PositionNode
+from amonite.node import PositionNode
 
 
 class ShapeNode(PositionNode):
